summaryrefslogtreecommitdiffstats
path: root/knetwortdeconf
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:10:12 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:10:12 -0600
commit189e536f1a74ecc2d9dcf35b9f5b3d54a2d1901e (patch)
tree52d62ad83db1551dd15dc147b4af4cacaae6e850 /knetwortdeconf
parent58cb2c2c17b1e6dd48cbfbcb69ec2f50f1ced9ee (diff)
downloadtdeadmin-189e536f1a74ecc2d9dcf35b9f5b3d54a2d1901e.tar.gz
tdeadmin-189e536f1a74ecc2d9dcf35b9f5b3d54a2d1901e.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'knetwortdeconf')
-rw-r--r--knetwortdeconf/knetwortdeconf/kaddknownhostdlg.ui2
-rw-r--r--knetwortdeconf/knetwortdeconf/knetwortdeconf.cpp16
-rw-r--r--knetwortdeconf/knetwortdeconf/knetwortdeconf.h10
-rw-r--r--knetwortdeconf/knetwortdeconf/knetwortdeconfdlg.ui8
-rw-r--r--knetwortdeconf/knetwortdeconf/knetwortdeconfigparser.cpp2
-rw-r--r--knetwortdeconf/knetwortdeconf/kselectdistrodlg.ui12
6 files changed, 25 insertions, 25 deletions
diff --git a/knetwortdeconf/knetwortdeconf/kaddknownhostdlg.ui b/knetwortdeconf/knetwortdeconf/kaddknownhostdlg.ui
index 430b37e..ef47e58 100644
--- a/knetwortdeconf/knetwortdeconf/kaddknownhostdlg.ui
+++ b/knetwortdeconf/knetwortdeconf/kaddknownhostdlg.ui
@@ -157,7 +157,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="KListBox">
+ <widget class="TDEListBox">
<property name="name">
<cstring>klbAliases</cstring>
</property>
diff --git a/knetwortdeconf/knetwortdeconf/knetwortdeconfdlg.ui b/knetwortdeconf/knetwortdeconf/knetwortdeconfdlg.ui
index 4834ca4..fd6abad 100644
--- a/knetwortdeconf/knetwortdeconf/knetwortdeconfdlg.ui
+++ b/knetwortdeconf/knetwortdeconf/knetwortdeconfdlg.ui
@@ -104,7 +104,7 @@
</spacer>
</hbox>
</widget>
- <widget class="KListView">
+ <widget class="TDEListView">
<column>
<property name="text">
<string>Interface</string>
@@ -452,7 +452,7 @@
<property name="spacing">
<number>6</number>
</property>
- <widget class="KListBox">
+ <widget class="TDEListBox">
<property name="name">
<cstring>klbDomainServerList</cstring>
</property>
@@ -640,7 +640,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="KListView">
+ <widget class="TDEListView">
<column>
<property name="text">
<string>IP Address</string>
@@ -786,7 +786,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="KListView" row="0" column="0" rowspan="2" colspan="1">
+ <widget class="TDEListView" row="0" column="0" rowspan="2" colspan="1">
<column>
<property name="text">
<string>Name</string>
diff --git a/knetwortdeconf/knetwortdeconf/knetwortdeconfigparser.cpp b/knetwortdeconf/knetwortdeconf/knetwortdeconfigparser.cpp
index a9fa230..27d236a 100644
--- a/knetwortdeconf/knetwortdeconf/knetwortdeconfigparser.cpp
+++ b/knetwortdeconf/knetwortdeconf/knetwortdeconfigparser.cpp
@@ -1073,7 +1073,7 @@ TQString KNetworkConfigParser::getPlatformInfo(TQDomElement platform){
}
/** Shows the dialog with all the supported platforms by GST. */
void KNetworkConfigParser::showSupportedPlatformsDialogSlot(){
- KSelectDistroDlg* dialog = new KSelectDistroDlg(0, 0);
+ TDESelectDistroDlg* dialog = new TDESelectDistroDlg(0, 0);
for ( TQStringList::Iterator it = supportedPlatformsList.begin(); it != supportedPlatformsList.end(); ++it )
{
diff --git a/knetwortdeconf/knetwortdeconf/kselectdistrodlg.ui b/knetwortdeconf/knetwortdeconf/kselectdistrodlg.ui
index d1d04ee..5baaebb 100644
--- a/knetwortdeconf/knetwortdeconf/kselectdistrodlg.ui
+++ b/knetwortdeconf/knetwortdeconf/kselectdistrodlg.ui
@@ -1,8 +1,8 @@
<!DOCTYPE UI><UI version="3.3" stdsetdef="1">
-<class>KSelectDistroDlg</class>
+<class>TDESelectDistroDlg</class>
<widget class="KDialog">
<property name="name">
- <cstring>KSelectDistroDlg</cstring>
+ <cstring>TDESelectDistroDlg</cstring>
</property>
<property name="geometry">
<rect>
@@ -25,7 +25,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="KListBox" row="2" column="0" rowspan="1" colspan="4">
+ <widget class="TDEListBox" row="2" column="0" rowspan="1" colspan="4">
<property name="name">
<cstring>klbDistroList</cstring>
</property>
@@ -113,19 +113,19 @@
<connection>
<sender>kpbOk</sender>
<signal>clicked()</signal>
- <receiver>KSelectDistroDlg</receiver>
+ <receiver>TDESelectDistroDlg</receiver>
<slot>accept()</slot>
</connection>
<connection>
<sender>kpbCancel</sender>
<signal>clicked()</signal>
- <receiver>KSelectDistroDlg</receiver>
+ <receiver>TDESelectDistroDlg</receiver>
<slot>reject()</slot>
</connection>
<connection>
<sender>klbDistroList</sender>
<signal>doubleClicked(TQListBoxItem*)</signal>
- <receiver>KSelectDistroDlg</receiver>
+ <receiver>TDESelectDistroDlg</receiver>
<slot>accept()</slot>
</connection>
</connections>
diff --git a/knetwortdeconf/knetwortdeconf/knetwortdeconf.cpp b/knetwortdeconf/knetwortdeconf/knetwortdeconf.cpp
index 3a01a60..4e1bd9b 100644
--- a/knetwortdeconf/knetwortdeconf/knetwortdeconf.cpp
+++ b/knetwortdeconf/knetwortdeconf/knetwortdeconf.cpp
@@ -38,9 +38,9 @@ KNetworkConf::KNetworkConf(TQWidget *parent, const char *name) : DCOPObject("KNe
connect(config,TQT_SIGNAL(readyLoadingNetworkInfo()),this,TQT_SLOT(enableSignals()));
connect(config, TQT_SIGNAL(setReadOnly(bool)),this,TQT_SLOT(setReadOnlySlot(bool)));
connect(klvCardList,
- TQT_SIGNAL(contextMenu(KListView*,TQListViewItem*,const TQPoint&)),
+ TQT_SIGNAL(contextMenu(TDEListView*,TQListViewItem*,const TQPoint&)),
this,
- TQT_SLOT(showInterfaceContextMenuSlot(KListView*,TQListViewItem*, const TQPoint&)));
+ TQT_SLOT(showInterfaceContextMenuSlot(TDEListView*,TQListViewItem*, const TQPoint&)));
// Register with DCOP - No longer needed as now we are a kcontrol module?
if ( !kapp->dcopClient()->isRegistered() ) {
@@ -634,7 +634,7 @@ void KNetworkConf::saveInfoSlot(){
}
}
/** Creates a TQStringList with the IP addresses contained in the TQListBox of name servers. */
-TQStringList KNetworkConf::getNamserversList(KListBox * serverList){
+TQStringList KNetworkConf::getNamserversList(TDEListBox * serverList){
TQStringList list;
for (unsigned i = 0; i < serverList->count(); i++)
{
@@ -642,8 +642,8 @@ TQStringList KNetworkConf::getNamserversList(KListBox * serverList){
}
return list;
}
-/** Creates a TQPtrList<KKownHostInfo> with the info contained in the KListView of name servers. */
-TQPtrList<KKnownHostInfo> KNetworkConf::getKnownHostsList(KListView * hostsList){
+/** Creates a TQPtrList<KKownHostInfo> with the info contained in the TDEListView of name servers. */
+TQPtrList<KKnownHostInfo> KNetworkConf::getKnownHostsList(TDEListView * hostsList){
TQPtrList<KKnownHostInfo> list;
TQListViewItem *it = hostsList->firstChild();
for (int i = 0; i < hostsList->childCount(); i++)
@@ -860,7 +860,7 @@ void KNetworkConf::disableInterfaceSlot()
changeDeviceState(dev->getDeviceName(),DEVICE_UP);
}
/** Adds a new host to the KListView that has the known hosts. */
void KNetworkConf::addKnownHostSlot(){
KAddKnownHostDlg dlg(this,0);
dlg.setCaption(i18n("Add New Static Host"));
@@ -977,9 +977,9 @@ void KNetworkConf::setReadOnlySlot(bool state)
}
/*Shows a context menu when right-clicking in the interface list*/
-void KNetworkConf::showInterfaceContextMenuSlot(KListView* lv, TQListViewItem* lvi, const TQPoint& pt)
+void KNetworkConf::showInterfaceContextMenuSlot(TDEListView* lv, TQListViewItem* lvi, const TQPoint& pt)
{
- KPopupMenu *context = new KPopupMenu( this );
+ TDEPopupMenu *context = new TDEPopupMenu( this );
TQ_CHECK_PTR( context );
context->insertItem( "&Enable Interface", this, TQT_SLOT(enableInterfaceSlot()));
context->insertItem( "&Disable Interface", this, TQT_SLOT(disableInterfaceSlot()));
@@ -860,7 +860,7 @@ void KNetworkConf::disableInterfaceSlot()
changeDeviceState(dev->getDeviceName(),DEVICE_UP);
}
-/** Adds a new host to the KListView that has the known hosts. */
+/** Adds a new host to the TDEListView that has the known hosts. */
void KNetworkConf::addKnownHostSlot(){
KAddKnownHostDlg dlg(this,0);
diff --git a/knetwortdeconf/knetwortdeconf/knetwortdeconf.h b/knetwortdeconf/knetwortdeconf/knetwortdeconf.h
index ce1bf15..5948678 100644
--- a/knetwortdeconf/knetwortdeconf/knetwortdeconf.h
+++ b/knetwortdeconf/knetwortdeconf/knetwortdeconf.h
@@ -103,9 +103,9 @@ class KNetworkConf : public KNetworkConfDlg, virtual public KNetworkConfIface
KNetworkInterface * getDeviceInfo(TQString device);
TQString getDeviceName(TQString ipAddr);
/** Creates a TQStringList with the IP addresses contained in the TQListBox of name servers. */
- TQStringList getNamserversList(KListBox * serverList);
-/** Creates a TQPtrList<KKownHostInfo> with the info contained in the KListView of name servers. */
- TQPtrList<KKnownHostInfo> getKnownHostsList(KListView * hostsList);
+ TQStringList getNamserversList(TDEListBox * serverList);
+/** Creates a TQPtrList<KKownHostInfo> with the info contained in the TDEListView of name servers. */
+ TQPtrList<KKnownHostInfo> getKnownHostsList(TDEListView * hostsList);
TQString currentDevice;
KRoutingInfo *routingInfo;
KDNSInfo *dnsInfo;
@@ -176,7 +176,7 @@ class KNetworkConf : public KNetworkConfDlg, virtual public KNetworkConfIface
/** Sets the TQPushButton::autoResize() in true for all buttons. */
void makeButtonsResizeable();
/** Adds a new host to the KListView that has the known hosts. */
void addKnownHostSlot();
void aboutSlot();
/** Edits the info about a known host. */
@@ -193,7 +193,7 @@ class KNetworkConf : public KNetworkConfDlg, virtual public KNetworkConfIface
bool isDeviceActive(const TQString &device, const TQString &ifconfigOutput);
/*Shows a context menu when right-clicking in the interface list*/
- void showInterfaceContextMenuSlot(KListView*, TQListViewItem*, const TQPoint&);
+ void showInterfaceContextMenuSlot(TDEListView*, TQListViewItem*, const TQPoint&);
/** Enable some signals in the GUI that need to be enabled *after* the loading of the network info is done.*/
void enableSignals ();
@@ -176,7 +176,7 @@ class KNetworkConf : public KNetworkConfDlg, virtual public KNetworkConfIface
/** Sets the TQPushButton::autoResize() in true for all buttons. */
void makeButtonsResizeable();
- /** Adds a new host to the KListView that has the known hosts. */
+ /** Adds a new host to the TDEListView that has the known hosts. */
void addKnownHostSlot();
void aboutSlot();